# Generated by Django 1.10.2 on 2016-10-30 12:13
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_chatterbot', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='statement',
            name='extra_data',
            field=models.CharField(default='{}', max_length=500),
            preserve_default=False,
        ),
    ]
