# Generated by Django 1.11 on 2017-07-18 00:16
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('django_chatterbot', '0006_create_conversation'),
    ]

    operations = [
        migrations.AddField(
            model_name='response',
            name='created_at',
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text='The date and time that this response was created at.'
            ),
        ),
    ]
